<?php

namespace Drupal\component_schema\Component\Schema;

use Drupal\Core\Template\Attribute;

trait ComponentVariableAttributeProviderTrait {

  /**
   * Adds classes or merges them on to array of existing CSS classes.
   *
   * @param \Drupal\Core\Template\Attribute $attribute
   *   An Attribute object.
   *
   * @return $this
   */
  protected abstract function addClass();

  /**
   * Sets values for an HTML attribute.
   *
   * @param \Drupal\Core\Template\Attribute $attribute
   *   An Attribute object.
   *
   * @return $this
   *   An Attribute object.
   */
  protected abstract function setAttribute();

  /**
   * {@inheritdoc}
   */
  public function initializeValue(&$value, Attribute $attribute = NULL) {
    // Set a default value.
    if (empty($value)) {
      $value = $this->getDataDefinition()->getDefault();
    }

    // Provide a class.
    if ($this->getDataDefinition()->providesClass()) {
      $this->addClass($value, $attribute);
    }

    // Provide an attribute.
    if ($this->getDataDefinition()->providesAttribute()) {
      $this->setAttribute($value, $attribute);
    }

    $this->processBreakpoints($value, $attribute);
  }

  /**
   * Processes breakpoints.
   *
   * @param mixed &$value
   *   A component variable value.
   * @param \Drupal\Core\Template\Attribute $attribute
   *   An Attribute object.
   *
   * @todo Write this method.
   * @see https://www.drupal.org/project/component_schema/issues/3154376
   */
  protected function processBreakpoints(&$value, Attribute $attribute) {

  }

}
