<?php

namespace Drupal\component_schema\Component\Schema;

use Drupal\Core\TypedData\DataDefinitionInterface;

/**
 * Interface for typed component variable data definitions.
 */
interface ComponentVariableDataDefinitionInterface extends DataDefinitionInterface {

  /**
   * Gets the URL of a page with documentation on the variable.
   *
   * @return string|NULL
   *   The URL value or NULL if none.
   */
  public function getDocumentationUrl();

  /**
   * Gets the default value for a variable.
   *
   * @return string|NULL
   *   The default value or NULL if none.
   */
  public function getDefault();

  /**
   * Gets the preview value for a variable.
   *
   * A preview value is suitable for applying to a component as sample content
   * in a preview context.
   *
   * @return string|NULL
   *   The preview value or NULL if none.
   */
  public function getPreview();

  /**
   * Gets the valid options for a variable.
   *
   * @return array|NULL
   *   The options value where keys are machine names and values are
   *   human-readable lables, or NULL if none.
   */
  public function getOptions();

  /**
   * Determines if this element allows NULL as a value.
   *
   * @return bool
   *   TRUE if NULL is a valid value, FALSE otherwise.
   */
  public function isNullable();

}
